package com.javaxpert.books.osgi.test.commands;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.PrintStream;

import org.apache.felix.shell.Command;

import aQute.bnd.annotation.component.Component;
import aQute.bnd.annotation.component.Reference;

import com.javaxpert.books.osgi.businessobjects.MyBusinessType;
import com.javaxpert.books.osgi.repository.api.IClassesRepository;
import com.javaxpert.books.osgi.xml.api.IXMLSerializer;

@Component
public class LaunchMarshallingCommand implements Command {
	private IXMLSerializer serializer;
	private IClassesRepository repository;
	// -------------------------------------------------------
	// getters & setters pour injection de dependances
	// via SCR OSGi
	// -------------------------------------------------------
	@Reference
	public void setRepository(IClassesRepository repository){
		this.repository=repository;
	}//setRepository()
	
	public void unsetRepository(IClassesRepository repository){
		//unset if not used
		this.repository=null;
	}//unsetRepository()
	
	@Reference
	public void setSerializer(IXMLSerializer serializer){
		this.serializer=serializer;
	}//setSerializer()
	
	public void unsetSerializer(IXMLSerializer serializer){
		// unref if not used
		serializer=null;
	}//unsetSerializer()
	
	// -------------------------------------------------------------
	// methodes callbacks pour l'interface Command
	// chaque commande doit :
	// 1- avoir un nom
	// 2 - fournir une aide sommaire
	// 3 - avoir une description courte
	// 4 - être implémentée par le biais de la commande execute()
	// -------------------------------------------------------------
	@Override
	//code de la commande ....
	// ici il s'agit simplement d'enregistrer une classe aupres du service de
	// repository de classes puis d'invoquer la serialisation XMl d'une instance de 
	// cette classe...
	public void execute(String arg0, PrintStream arg1, PrintStream arg2) {
		try{
			repository.publishClass(MyBusinessType.class);
			MyBusinessType myobject = new MyBusinessType(12, "toto","somewhere");
			//String xml_string = new ByteArrayOutputStream(serializer.marshall2XML(myobject)).toString();
		}catch(Exception e){
			
		}
	}//execute()

	@Override
	// nom de la commande à saisir dans le shell
	public String getName() {
		return "launchMarshallCmd";
	}

	@Override
	// descriptif de la commande
	public String getShortDescription() {
		return "launch XML marshalling ";
	}

	@Override
	// illustre l'utilisation typique de la commande
	public String getUsage() {
		return  ">launchMarshallCmd <output>\nWhere output is the filename to be used for storing XML data";
	}

}
