package com.javaxpert.books.osgi.whiteboard;

import java.io.IOException;
import java.util.Hashtable;

import javax.servlet.Servlet;
import javax.servlet.ServletConfig;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.osgi.framework.BundleContext;
import org.osgi.service.log.LogService;

import aQute.bnd.annotation.component.Activate;
import aQute.bnd.annotation.component.Component;
import aQute.bnd.annotation.component.Reference;
@Component(immediate=true)
/** 
 * <p> 
 * Cette classe illustre l'enregistrement d'une servlet par le biais du D.P Whiteboard
 * OSGi....Ici pas besoin d'obtenir une référence sur  l'HttpService puis d'invoquer
 * une méthode ...L'enregistrement d'un service OSGi avec en type de service Servlet
 * déclenchera automatiquement l'enregistrement auprès de l'HttpService et l'enregistrement du 
 * contexte sur le conteneur Web.
 * </p>
 * @author romje,jerome@javaxpert.com
 *
 */
public class MyServlet extends HttpServlet {
	private LogService log;
	@Reference
	public void setLog(LogService service){
		log=service;
	}
	
	public void unsetLog(LogService service){
		// TODO best code
		log=null;
	}
	
	@Activate
	public void activate(BundleContext bc){
		log.log(LogService.LOG_INFO, "Activation de la Servlet...");
		 Hashtable props = new Hashtable();
		 props.put("alias", "/hello");
		 props.put("init.message", "Hello World!");
		// enregistrement de la servlet auprès de l'HttpService 
		// cf WhiteBoard
		// attention il faut utiliser la classe Servlet et non HttpServlet
		bc.registerService(Servlet.class.getName(), this, props);
	}
	
	@Override
	protected void doGet(HttpServletRequest req, HttpServletResponse resp)
			throws ServletException, IOException {
		System.out.println("get invoked");
		resp.getWriter().println("Invocation de la servlet réussie");
		resp.flushBuffer();
	}

	@Override
	public void init(ServletConfig config) throws ServletException {
		// TODO Auto-generated method stub
		super.init(config);
	}
	
}
